@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2013 Jeffrey Stedfast
+ *  Copyright (C) 2000-2020 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -73,17 +73,13 @@ typedef struct {
 /**
  * GMimeStream:
  * @parent_object: parent #GObject
- * @super_stream: parent stream if this is a substream
- * @position: the current stream position
- * @bound_start: start boundary of the stream
- * @bound_end: end boundary of the stream
  *
  * Abstract I/O stream class.
  **/
 struct _GMimeStream {
+	/* <private> */
 	GObject parent_object;
 	
-	/* <private> */
 	GMimeStream *super_stream;
 	
 	gint64 position;
@@ -130,9 +126,9 @@ void      g_mime_stream_set_bounds (GMimeStream *stream, gint64 start, gint64 en
 ssize_t   g_mime_stream_write_string (GMimeStream *stream, const char *str);
 ssize_t   g_mime_stream_printf       (GMimeStream *stream, const char *fmt, ...) G_GNUC_PRINTF (2, 3);
 
-ssize_t   g_mime_stream_write_to_stream (GMimeStream *src, GMimeStream *dest);
+gint64    g_mime_stream_write_to_stream (GMimeStream *src, GMimeStream *dest);
 
-ssize_t   g_mime_stream_writev (GMimeStream *stream, GMimeStreamIOVector *vector, size_t count);
+gint64    g_mime_stream_writev (GMimeStream *stream, GMimeStreamIOVector *vector, size_t count);
 
 G_END_DECLS
 
